Header menu logo FCQRS

SagaTransition<'State> Type

Represents the next state transition for a saga after processing an event or timeout.

Union cases

Union case Description

NextState 'State

Full Usage: NextState 'State

Parameters:
    Item : 'State

The saga should transition to a new state

Item : 'State

Stay

Full Usage: Stay

The saga should stay in current state without changes

StayExpecting Expectation

Full Usage: StayExpecting Expectation

Parameters:

Stay in the current state, but declare that the expectation's commands anticipate a state transition: the framework re-sends them on the schedule and delivers ExpectationExhausted past the deadline.

Item : Expectation

StopSaga

Full Usage: StopSaga

The saga should stop and terminate

Instance members

Instance member Description

this.IsNextState

Full Usage: this.IsNextState

Returns: bool
Returns: bool

this.IsStay

Full Usage: this.IsStay

Returns: bool
Returns: bool

this.IsStayExpecting

Full Usage: this.IsStayExpecting

Returns: bool
Returns: bool

this.IsStopSaga

Full Usage: this.IsStopSaga

Returns: bool
Returns: bool

Type something to start searching.