Header menu logo FCQRS

SagaCommands Type

C#-friendly saga command targeting

Static members

Static member Description

SagaCommands.ToActor(actorRef, command)

Full Usage: SagaCommands.ToActor(actorRef, command)

Parameters:
Returns: ExecuteCommand

Create a command to send to an actor ref

actorRef : IActorRef<obj>
command : obj
Returns: ExecuteCommand

SagaCommands.ToActorDelayed(actorRef, command, delayMs, taskName)

Full Usage: SagaCommands.ToActorDelayed(actorRef, command, delayMs, taskName)

Parameters:
    actorRef : IActorRef<obj>
    command : obj
    delayMs : int64
    taskName : string

Returns: ExecuteCommand

Create a delayed command to a concrete actor ref.

actorRef : IActorRef<obj>
command : obj
delayMs : int64
taskName : string
Returns: ExecuteCommand

SagaCommands.ToAggregate(factory, aggregateId, command)

Full Usage: SagaCommands.ToAggregate(factory, aggregateId, command)

Parameters:
Returns: ExecuteCommand

Create a command to send to a named aggregate

factory : AggregateFactory
aggregateId : string
command : obj
Returns: ExecuteCommand

SagaCommands.ToAggregateDelayed(factory, entityId, command, delayMs, taskName)

Full Usage: SagaCommands.ToAggregateDelayed(factory, entityId, command, delayMs, taskName)

Parameters:
    factory : AggregateFactory
    entityId : string
    command : obj
    delayMs : int64
    taskName : string

Returns: ExecuteCommand

Create a delayed command to a specific aggregate instance.

factory : AggregateFactory
entityId : string
command : obj
delayMs : int64
taskName : string
Returns: ExecuteCommand

SagaCommands.ToOriginator(factory, command)

Full Usage: SagaCommands.ToOriginator(factory, command)

Parameters:
Returns: ExecuteCommand

Create a command to send to the originator aggregate

factory : AggregateFactory
command : obj
Returns: ExecuteCommand

SagaCommands.ToOriginatorDelayed(factory, command, delayMs, taskName)

Full Usage: SagaCommands.ToOriginatorDelayed(factory, command, delayMs, taskName)

Parameters:
Returns: ExecuteCommand

Create a delayed command

factory : AggregateFactory
command : obj
delayMs : int64
taskName : string
Returns: ExecuteCommand

SagaCommands.ToSelf(command)

Full Usage: SagaCommands.ToSelf(command)

Parameters:
    command : obj

Returns: ExecuteCommand

Create a command to the saga itself (raw; lands in HandleEvent) — e.g. timeouts.

command : obj
Returns: ExecuteCommand

SagaCommands.ToSelfDelayed(command, delayMs, taskName)

Full Usage: SagaCommands.ToSelfDelayed(command, delayMs, taskName)

Parameters:
    command : obj
    delayMs : int64
    taskName : string

Returns: ExecuteCommand

Schedule a message to the saga itself after a delay — the idiomatic saga timeout.

command : obj
delayMs : int64
taskName : string
Returns: ExecuteCommand

Type something to start searching.