IEnvelope Type
Non-generic access to a Command<_>/Event<_> payload, so a boxed message can be unwrapped to its details without knowing the concrete payload type.
Instance members
| Instance member | Description |
Full Usage:
this.Payload
Returns: obj
Modifiers: abstract |
FCQRS